%
% Copyright (c) 2015, Yarpiz (www.yarpiz.com)
% All rights reserved. Please read the "license.txt" for license terms.
%
% Project Code: YPAP113
% Project Title: Solving Economic Dispatching using Nested PSO in MATLAB
% Publisher: Yarpiz (www.yarpiz.com)
% 
% Developer: S. Mostapha Kalami Heris (Member of Yarpiz Team)
% 
% Contact Info: sm.kalami@gmail.com, info@yarpiz.com
%

function [z, out]=MyCostExt(x,extmodel)

    M=extmodel.nPlant;

    k=ParseSolutionExt(x,M);
    
    F=zeros(1,M);
    for i=1:M
        ki=k(i);
        if ki==0
            F(i)=extmodel.EmptyPlant.F;
        else
            F(i)=extmodel.Plants.F(ki);
        end
    end
    
    FTotal=sum(F);
    
    intmodel=CreateInternalModel(k,extmodel);
    results=RunInternalPSO(intmodel);
    
    BestEconomicDispatchCost=results.BestSol.Cost;
    
    wext=1;
    wint=1;
    z = wext*FTotal + wint*BestEconomicDispatchCost;
    
    out.k=k;
    out.F=F;
    out.FTotal=FTotal;
    out.ED.model=intmodel;
    out.ED.BestSol=results.BestSol;
    out.ED.BestCost=results.BestCost;
    out.z=z;

end